# -*- coding: UTF-8 -*-
"""
Module de tests unitaires pour les variables multiples

"""
import autopath
from os.path import join 
from creole.parsedico import parse_dico

from era.backend.cheetah import Multivar
from creole.cfgparser import EoleDict

from py.test import raises

def setup_module(module):
    """
    creation du dico creole de travail
    """
    creoledir = join(autopath.HERE, "data")
    creole_file = join(autopath.HERE, "data", "multi.xml")
    module.dico = EoleDict(templatedir=creoledir)
    module.dico.read(creole_file)

def _test(line):
    """
        Multivar factory avec un dico de test (data/multi.xml)
    """
    m = Multivar(line, creole_dico=dico)
    return list(m.process())

def test_novar():
    "pas de variable creole dans la ligne"

    line = ["sdfsfsfd "]
    assert _test(line) == ['sdfsfsfd ']

#def test_nonexist():
#    "il y a une variable mais elle n'existe pas dans le dico"

#    line = ["""sdf sdf %%name sdfsdfsdf """]
# FIXME lever un warning

def test_nomulti():
    """
        il y a une variable, elle est présente dans le dico, 
        mais elle n'est pas multi-valuée
    """

    line = """sdf sdf %%ssh_permit_root sdfsdfsdf 
""".split('\n')
    assert _test(line) == ['sdf sdf %%ssh_permit_root sdfsdfsdf ', '']

#def test_nomulti_asmulti():
#    """
#        utilisation d'une variable multi-valuée 
#        alors qu'elle n'est pas déclarée comme multi-valuée dans créole
#    
#    :name: n'est pas multi-valuée
#    """
#    line = """sdf sdf %%name[2] sdfsdfsdf##""".split('\n')
# FIXME lever un warning

#def test_multi_index_exceeded():
#    """
#        utilisation d'un index eroné dans un indice de variable multi-valuée
#    multi_name[i] avec i appartient [0,2]
#    """
#    line = """sdf sdf %%multi_name[5] bla bla
#""".split('\n')
#    # 5 est trop grand
# FIXME lever un warning

def test_multi_indicee():
    """
        présence dans le dico créole d'une variable multivaluée indexée 
    """
    line = """sdf sdf %%ip_ssh_eth0[1] sdfsdfsdf 
""".split('\n')
    assert _test(line) == ['sdf sdf %%ip_ssh_eth0[1] sdfsdfsdf ', '']    

def test_maitre():
    """
        présence d'une variable maître sans esclave
        dans le dico la variable ip_ssh est maitre
        u'ip_ssh_eth1': [u'netmask_ssh_eth1']
        
    """
    line = """sdf sdf %%ip_ssh_eth0 sdfsdfsdf""".split('\n')
    assert _test(line) == ['%for %%v in %%ip_ssh_eth0\n', 'sdf sdf %%v sdfsdfsdf\n', '%end for\n']

def test_esclave_seul():
    """
        présence d'une variable esclave sans présence de maître
        u'ip_ssh_eth1': [u'netmask_ssh_eth1']        
        
        ça itère comme sur du multivalué normal
    """
    line = """sdf sdf %%netmask_ssh_eth1 sdfsdfsdf""".split('\n')
    assert _test(line) == ['sdf sdf %%netmask_ssh_eth1 sdfsdfsdf']
    
def test_esclave_indicee_directement():
    """
        présence d'une variable multivaluée indicée esclave 
        %%name[1]

        pour l'instant la notation %%name[2] n'est pas accessible pour 
        une variable esclave
    """
    # FIXME lever un WARNING    
    
def test_maitre_esclave():
    """
        présence d'une variable maitre **et** de variables esclaves lui appartenant
        u'ip_ssh_eth1': [u'netmask_ssh_eth1']
        
    """
    line = ["""sdf sdf %%ip_ssh_eth1 sdfsdfsdf %%netmask_ssh_eth1 sdfsdfsdf"""]    
    assert _test(line) == ['%for %%v in %%ip_ssh_eth1\n', 'sdf sdf %%v sdfsdfsdf %%v.netmask_ssh_eth1 sdfsdfsdf\n', '%end for\n']
    
def test_maitre_autre_esclave():
    """
        présence d'une variable maître et d'une variable esclave ne lui appartenant pas
    """
    # FIXME lever un WARNING
    
